@@ -488,52 +488,44 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		return;		      
 	}
 	else if (valid == BRASERO_SESSION_NO_INPUT_MEDIUM) {
-		GtkWidget *message;
-
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (priv->message_input,
-							      _("Please insert a disc holding data."),
-							      _("There is no inserted disc to copy."),
-							      -1,
-							      BRASERO_NOTIFY_CONTEXT_SIZE);
+			brasero_notify_message_add (priv->message_input,
+			                            _("Please insert a disc holding data."),
+			                            _("There is no inserted disc to copy."),
+			                            -1,
+			                            BRASERO_NOTIFY_CONTEXT_SIZE);
 		}
 	}
 	else if (valid == BRASERO_SESSION_NO_INPUT_IMAGE) {
-		GtkWidget *message;
-
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (priv->message_input,
-							      _("Please select a disc image."),
-							      _("There is no selected disc image."),
-							      -1,
-							      BRASERO_NOTIFY_CONTEXT_SIZE);
+			brasero_notify_message_add (priv->message_input,
+			                            _("Please select a disc image."),
+			                            _("There is no selected disc image."),
+			                            -1,
+			                            BRASERO_NOTIFY_CONTEXT_SIZE);
 		}
 	}
 	else if (valid == BRASERO_SESSION_UNKNOWN_IMAGE) {
-		GtkWidget *message;
-
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (priv->message_input,
-							      /* Translators: this is a disc image not a picture */
-							      C_("disc", "Please select another image."),
-							      _("It doesn't appear to be a valid disc image or a valid cue file."),
-							      -1,
-							      BRASERO_NOTIFY_CONTEXT_SIZE);
+			brasero_notify_message_add (priv->message_input,
+			                            /* Translators: this is a disc image not a picture */
+			                            C_("disc", "Please select another image."),
+			                            _("It doesn't appear to be a valid disc image or a valid cue file."),
+			                            -1,
+			                            BRASERO_NOTIFY_CONTEXT_SIZE);
 		}
 	}
 	else if (valid == BRASERO_SESSION_DISC_PROTECTED) {
-		GtkWidget *message;
-
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (priv->message_input,
-							      _("Please insert a disc that is not copy protected."),
-							      _("All required applications and libraries are not installed."),
-							      -1,
-							      BRASERO_NOTIFY_CONTEXT_SIZE);
+			brasero_notify_message_add (priv->message_input,
+			                            _("Please insert a disc that is not copy protected."),
+			                            _("All required applications and libraries are not installed."),
+			                            -1,
+			                            BRASERO_NOTIFY_CONTEXT_SIZE);
 		}
 	}
 	else if (valid == BRASERO_SESSION_NOT_SUPPORTED) {
@@ -545,7 +537,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 	}
 	else if (valid == BRASERO_SESSION_OVERBURN_NECESSARY) {
 		GtkWidget *message;
-
+		
 		message = brasero_notify_message_add (priv->message_output,
 						      _("Would you like to burn beyond the disc's reported capacity?"),
 						      _("The data size is too large for the disc and you must remove files from the selection otherwise."
@@ -588,7 +580,6 @@ brasero_burn_options_valid_cb (BraseroSessionCfg *session,
 static void
 brasero_burn_options_init (BraseroBurnOptions *object)
 {
-	gtk_dialog_set_has_separator (GTK_DIALOG (object), FALSE);
 }
 
 /**
@@ -780,7 +771,6 @@ brasero_status_dialog_uri_has_image (BraseroTrackDataCfg *track,
 {
 	gint answer;
 	gchar *name;
-	gchar *string;
 	GtkWidget *button;
 	GtkWidget *dialog;
 	gboolean was_visible = FALSE;
@@ -802,10 +792,11 @@ brasero_status_dialog_uri_has_image (BraseroTrackDataCfg *track,
 	                          gtk_window_get_icon_name (GTK_WINDOW (self)));
 
 	name = brasero_utils_get_uri_name (uri);
-	/* Translators: %s is the name of the image */
-	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burned."), name);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
-	g_free (string);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			/* Translators: %s is the name of the image */
+			_("There is only one selected file (\"%s\"). "
+			  "It is the image of a disc and its contents can be burned."),
+			name);
 	g_free (name);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
@@ -1132,7 +1123,7 @@ brasero_burn_options_install_missing (BraseroPluginErrorType type,
 	int xid = 0;
 
 	/* Get the xid */
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (user_data)->window));
+	xid = gdk_x11_window_get_xid (gtk_widget_get_window (GTK_WIDGET (user_data)));
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
@@ -1181,12 +1172,15 @@ brasero_burn_options_list_missing (BraseroPluginErrorType type,
 {
 	GString *string = user_data;
 
-	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
+	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP ||
+	    type == BRASERO_PLUGIN_ERROR_SYMBOLIC_LINK_APP ||
+	    type == BRASERO_PLUGIN_ERROR_WRONG_APP_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing application */
 		g_string_append_printf (string, _("%s (application)"), detail);
 	}
-	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY ||
+	         type == BRASERO_PLUGIN_ERROR_LIBRARY_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing library */
 		g_string_append_printf (string, _("%s (library)"), detail);
