@@ -132,7 +132,7 @@ brasero_playlist_increase_activity_counter (BraseroPlaylist *playlist)
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (window,
 				       cursor);
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 	playlist->priv->activity_counter++;
 }
